@@ -1,7 +1,8 @@
 package HTML::Linear::Element;
 # ABSTRACT: represent elements to populate HTML::Linear
 use strict;
-use common::sense;
+use utf8;
+use warnings qw(all);
 
 use Digest::SHA;
 use List::Util qw(sum);
@@ -9,7 +10,7 @@ use Any::Moose;
 
 use HTML::Linear::Path;
 
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 
 has attributes  => (is => 'rw', isa => 'HashRef[Str]', default => sub { {} }, auto_deref => 1);
@@ -106,7 +107,7 @@ HTML::Linear::Element - represent elements to populate HTML::Linear
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
